@@ -5,7 +5,7 @@ from .common import LineageClient, LocalArtifact, S3Artifact
 from .config import config, s3_config, set_config, set_s3_config
 from .context import Context
 from .dag import DAG
-from .executor import Executor, RemoteExecutor
+from .executor import ContainerExecutor, Executor, RemoteExecutor
 from .io import (AutonamedDict, IfExpression, InputArtifact, InputParameter,
                  Inputs, OutputArtifact, OutputParameter, Outputs,
                  if_expression)
@@ -34,7 +34,7 @@ __all__ = ["S3Artifact", "DAG", "Executor", "RemoteExecutor", "AutonamedDict",
            "Context", "randstr", "LocalArtifact", "set_config",
            "set_s3_config", "DockerSecret", "argo_sum", "argo_concat",
            "LineageClient", "Secret", "query_workflows",
-           "query_archived_workflows"]
+           "query_archived_workflows", "ContainerExecutor"]
 
 
 def import_func(s):
