@@ -51,7 +51,7 @@ class DispatcherExecutor(Executor):
         podman_executable: podman executable to run remotely
         remote_root: remote root path for working
         retry_on_submission_error: max retries on submission error
-        merge_sliced_step: handle multi slices in one dispatcher job
+        merge_sliced_step: handle multi slices in a single dispatcher job
     """
 
     def __init__(self,
@@ -179,7 +179,8 @@ class DispatcherExecutor(Executor):
             "group_size": 5,
             "envs": {
                 "DFLOW_WORKFLOW": "{{workflow.name}}",
-                "DFLOW_POD": "{{pod.name}}"
+                "DFLOW_POD": "{{pod.name}}",
+                "PYTHONUNBUFFERED": "true",
             }
         }
         if self.queue_name is not None:
@@ -211,7 +212,7 @@ class DispatcherExecutor(Executor):
             else self.remote_command
         cmd = ""
         if self.map_tmp_dir:
-            cmd += "sed -i \\\"s#\\\\$(pwd)#$(pwd)#g\\\" script && "
+            cmd += "sed -i \"s#\\$(pwd)#$(pwd)#g\" script && "
 
         cmd += run_script(template.image, remote_command,
                           self.docker_executable, self.singularity_executable,
@@ -246,10 +247,12 @@ class DispatcherExecutor(Executor):
         new_template.script += "with open('script', 'w') as f:\n"
         new_template.script += "    f.write(r\"\"\"\n"
         if self.map_tmp_dir:
-            new_template.script += render_script_with_tmp_root(template,
-                                                               "$(pwd)/tmp")
+            script = render_script_with_tmp_root(template, "$(pwd)/tmp")
         else:
-            new_template.script += template.script
+            script = template.script
+        # keep the script human-readable
+        script = script.replace("\"\"\"", "'''")
+        new_template.script += script
         new_template.script += "\"\"\")\n"
 
         if self.machine_dict["context_type"] == "Bohrium":
@@ -263,16 +266,16 @@ class DispatcherExecutor(Executor):
         new_template.script += "from dpdispatcher import Machine, Resources,"\
             " Task, Submission\n"
         new_template.script += "machine = Machine.load_from_dict(json.loads("\
-            "'%s'))\n" % json.dumps(self.machine_dict)
+            "r'%s'))\n" % json.dumps(self.machine_dict)
         new_template.script += "resources = Resources.load_from_dict(json."\
-            "loads('%s'))\n" % json.dumps(self.resources_dict)
+            "loads(r'%s'))\n" % json.dumps(self.resources_dict)
         if new_template.envs is not None:
             for k in new_template.envs.keys():
                 new_template.script += "resources.envs['%s'] = "\
                     "os.environ.get('%s')\n" % (k, k)
         new_template.script += "resources.envs['ARGO_TEMPLATE'] = "\
             "shlex.quote(os.environ.get('ARGO_TEMPLATE'))\n"
-        new_template.script += "task = Task.load_from_dict(json.loads('%s'))"\
+        new_template.script += "task = Task.load_from_dict(json.loads(r'%s'))"\
             "\n" % json.dumps(self.task_dict)
         new_template.script += "task.forward_files = list(filter("\
             "os.path.exists, task.forward_files))\n"
@@ -387,6 +390,7 @@ class DispatcherExecutor(Executor):
                 new_template.script += "            res.append(f.read())\n"
                 new_template.script += "with open('./%s', 'w') as f:\n" % path
                 new_template.script += "    f.write(json.dumps(res))\n"
+        new_template.script_rendered = True
 
         # workaround for unavailable exit code of Bohrium job
         # check output files explicitly
