@@ -7,7 +7,7 @@ from typing import Any, Dict, List, Optional, Union
 
 import jsonpickle
 
-from .common import LocalArtifact, S3Artifact
+from .common import LocalArtifact, S3Artifact, HTTPArtifact
 from .config import config, s3_config
 from .context_syntax import GLOBAL_CONTEXT
 from .executor import Executor
@@ -18,7 +18,8 @@ from .op_template import (OPTemplate, PythonScriptOPTemplate, ScriptOPTemplate,
 from .python import Slices
 from .resource import Resource
 from .util_ops import CheckNumSuccess, CheckSuccessRatio, InitArtifactForSlices
-from .utils import catalog_of_artifact, merge_dir, randstr, upload_artifact
+from .utils import (catalog_of_artifact, flatten, merge_dir, randstr,
+                    upload_artifact)
 
 try:
     from argo.workflows.client import (V1alpha1Arguments, V1alpha1ContinueOn,
@@ -1074,10 +1075,13 @@ class Step:
                         name].sub_path(art["subPath"])
             elif "oss" in art:
                 kwargs["artifacts"][name] = S3Artifact(
-                    key=art["oss"]["key"]).oss()
+                    key=art["oss"]["key"])
                 if "subPath" in art:
                     kwargs["artifacts"][name] = kwargs["artifacts"][
                         name].sub_path(art["subPath"])
+            elif "http" in art:
+                kwargs["artifacts"][name] = HTTPArtifact(
+                    url=art["http"]["url"])
         kwargs["key"] = kwargs["parameters"].get("dflow_key", None)
         return cls(**kwargs)
 
@@ -1163,6 +1167,46 @@ class Step:
                     self.template.render_script()
                 del self.template.inputs.artifacts[k]
                 del self.inputs.artifacts[k]
+            elif isinstance(v, dict):
+                self.template = self.template.copy()
+                slices = {}
+                flat_v = flatten(v)
+                for i, a in flat_v.items():
+                    vn = "dflow_%s_%s" % (k, i)
+                    self.template.inputs.artifacts[vn] = deepcopy(
+                        self.template.inputs.artifacts[k])
+                    self.inputs.artifacts[vn] = deepcopy(
+                        self.template.inputs.artifacts[vn])
+                    self.inputs.artifacts[vn].source = a
+                    if hasattr(a, "slice") and a.slice is not None:
+                        slices[i] = a.slice
+                    else:
+                        slices[i] = None
+                from .dag import DAG
+                from .steps import Steps
+                if isinstance(self.template, (Steps, DAG)):
+                    for step in self.template:
+                        for name, art in list(step.inputs.artifacts.items()):
+                            if art.source is self.template.inputs.artifacts[k]:
+                                step.set_artifacts({name: {
+                                    i: self.template.inputs.artifacts[
+                                        "dflow_%s_%s" % (k, i)]
+                                    if slice is None else
+                                    self.template.inputs.artifacts[
+                                        "dflow_%s_%s" % (k, i)][slice]
+                                    for i, slice in slices.items()}})
+                else:
+                    for i, a in flat_v.items():
+                        vn = "dflow_%s_%s" % (k, i)
+                        self.template.inputs.artifacts[vn].path = \
+                            "%s/inputs/artifacts/%s" % (self.template.tmp_root,
+                                                        vn)
+                    if any(map(lambda x: x is not None, slices.values())):
+                        self.template.input_artifact_slices[k] = slices
+                    self.template.keys_of_parts[k] = list(v.keys())
+                    self.template.render_script()
+                del self.template.inputs.artifacts[k]
+                del self.inputs.artifacts[k]
             else:
                 self.inputs.artifacts[k].source = v
                 if hasattr(v, "slice") and v.slice is not None:
@@ -1433,6 +1477,10 @@ class Step:
                         os.rmdir(path)
                         os.rename(path + ".bk", path)
                     art.source.local_path = path
+                elif isinstance(art.source, HTTPArtifact) and not hasattr(
+                        art.source, "local_path"):
+                    path = os.path.abspath("download/%s" % randstr())
+                    art.source.local_path = art.source.download(path=path)
                 if not hasattr(art.source, "local_path") and art.optional:
                     continue
                 steps.inputs.artifacts[name].local_path = art.source.local_path
@@ -1658,8 +1706,13 @@ class Step:
                     os.rmdir(path)
                     os.rename(path + ".bk", path)
                 art.source.local_path = path
-            if isinstance(art.source, (InputArtifact, OutputArtifact,
-                                       LocalArtifact, S3Artifact)):
+            elif isinstance(art.source, HTTPArtifact) and not hasattr(
+                    art.source, "local_path"):
+                path = os.path.abspath("download/%s" % randstr())
+                art.source.local_path = art.source.download(path=path)
+            if isinstance(
+                art.source, (InputArtifact, OutputArtifact, LocalArtifact,
+                             S3Artifact, HTTPArtifact)):
                 if art.sub_path is not None:
                     sub_path = art.sub_path
                     if item is not None:
@@ -1820,7 +1873,7 @@ class Step:
 
         # render variables in the script
         script = self.template.script
-        if self.executor is None:
+        if not self.template.script_rendered:
             if hasattr(self.template, "tmp_root"):
                 # do not modify self.template
                 template = deepcopy(self.template)
