@@ -129,6 +129,59 @@ def download_artifact(
     return assemble_path_list(path, remove=remove_catalog)
 
 
+def flatten(d: Union[list, dict]) -> dict:
+    def handle(obj, prefix):
+        if isinstance(obj, dict):
+            for k, v in obj.items():
+                key = prefix + "." + k if prefix else k
+                if isinstance(v, (list, dict)):
+                    handle(v, key)
+                else:
+                    flat[key] = v
+        elif isinstance(obj, list):
+            for i, v in enumerate(obj):
+                key = prefix + "." + str(i) if prefix else str(i)
+                if isinstance(v, (list, dict)):
+                    handle(v, key)
+                else:
+                    flat[key] = v
+    flat = {}
+    handle(d, "")
+    return flat
+
+
+def dict2list(d: dict):
+    for k, v in d.items():
+        if isinstance(v, dict):
+            d[k] = dict2list(v)
+    try:
+        lst = []
+        for k, v in d.items():
+            i = int(k)
+            if i < len(lst):
+                lst[i] = v
+            else:
+                lst += [None] * (i - len(lst)) + [v]
+        return lst
+    except Exception:
+        return d
+
+
+def expand(d: dict) -> Union[list, dict]:
+    exp = {}
+    for k, v in d.items():
+        fields = str(k).split(".")
+        tmp = exp
+        for field in fields[:-1]:
+            if field not in tmp:
+                tmp[field] = {}
+            tmp = tmp[field]
+        field = fields[-1]
+        tmp[field] = v
+    exp = dict2list(exp)
+    return exp
+
+
 def upload_artifact(
         path: Union[os.PathLike, List[os.PathLike], Set[os.PathLike],
                     Dict[str, os.PathLike], list, dict],
@@ -153,31 +206,13 @@ def upload_artifact(
         archive = config["archive_mode"]
     cwd = os.getcwd()
     with tempfile.TemporaryDirectory() as tmpdir:
-        path_list = []
-        pairs = []
-
-        def handle(obj, prefix):
-            if isinstance(obj, dict):
-                for k, v in obj.items():
-                    key = prefix + "." + k if prefix else k
-                    if isinstance(v, (list, dict)):
-                        handle(v, key)
-                    elif isinstance(v, (str, Path)):
-                        pairs.append((key, v))
-            elif isinstance(obj, list):
-                for i, v in enumerate(obj):
-                    key = prefix + "." + str(i) if prefix else str(i)
-                    if isinstance(v, (list, dict)):
-                        handle(v, key)
-                    elif isinstance(v, (str, Path)):
-                        pairs.append((key, v))
-
         if isinstance(path, dict):
-            handle(path, "")
+            pairs = flatten(path).items()
         elif isinstance(path, (list, set)):
             pairs = enumerate(path)
         else:
             pairs = [(0, path)]
+        path_list = []
         for i, p in pairs:
             logging.debug("upload artifact: handle path: %s" % p)
             if p is None:
@@ -500,52 +535,8 @@ def assemble_path_dict(art_path, remove=False):
     return path_dict
 
 
-def dict2list(d: dict):
-    for k, v in d.items():
-        if isinstance(v, dict):
-            d[k] = dict2list(v)
-    try:
-        lst = []
-        for k, v in d.items():
-            i = int(k)
-            if i < len(lst):
-                lst[i] = v
-            else:
-                lst += [None] * (i - len(lst)) + [v]
-        return lst
-    except Exception:
-        return d
-
-
 def assemble_path_nested_dict(art_path, remove=False):
-    path_dict = {}
-    if os.path.isdir(art_path):
-        dflow_list = []
-        catalog_dir = os.path.join(art_path, config["catalog_dir_name"])
-        if os.path.exists(catalog_dir):
-            for f in os.listdir(catalog_dir):
-                with open(os.path.join(catalog_dir, f), 'r') as fd:
-                    for item in jsonpickle.loads(fd.read())['path_list']:
-                        if item not in dflow_list:
-                            dflow_list.append(item)  # remove duplicate
-            if remove:
-                shutil.rmtree(catalog_dir)
-        if len(dflow_list) > 0:
-            for item in dflow_list:
-                fields = str(item["order"]).split(".")
-                tmp = path_dict
-                for field in fields[:-1]:
-                    if field not in tmp:
-                        tmp[field] = {}
-                    tmp = tmp[field]
-                field = fields[-1]
-                if item["dflow_list_item"] is None:
-                    tmp[field] = None
-                else:
-                    tmp[field] = os.path.join(
-                        art_path, item["dflow_list_item"])
-            path_dict = dict2list(path_dict)
-    return path_dict
+    return expand(assemble_path_dict(art_path, remove))
 
 
 def remove_empty_dir_tag(path):
@@ -650,6 +641,7 @@ def run_command(
     ) as sub:
         if input is not None:
             sub.stdin.write(bytes(input, encoding=sys.stdout.encoding))
+            sub.stdin.close()
         if print_oe:
             out = ""
             err = ""
